@@ -31,7 +31,7 @@ class FilamentDataset(Dataset):
     def __getitem__(self, idx):
         anno, class_name = self.data[idx]
         anno_tensor = torch.from_numpy(anno)
-        class_id = torch.tensor([class_name])
+        class_id = torch.tensor(class_name)
         return anno_tensor, class_id
 
 
@@ -50,5 +50,5 @@ if __name__ == "__main__":
     data_loader = FilamentDataLoader(dataset, 6, (1, 1, 1), 1, transforms=transforms1, image_dim= 256)
     # print(len(data_loader))
     for _,imgs, labels in data_loader:
-        print("Batch of images has shape: ", imgs.shape)
+        print("Batch of images has shape: ", imgs)
         print("Batch of labels has shape: ", labels)
\ No newline at end of file
