@@ -69,9 +69,12 @@ class FilamentDataLoader(DataLoader):
                     image = image.convert('RGB')
                 org_image = cv2.resize(np.array(org_image), self.image_dim)
                 org_images.append(torch.from_numpy(org_image))
-                image = cv2.resize(np.array(image), self.image_dim)
+                image = np.array(image, dtype = np.float32)
+                image = cv2.resize(image, self.image_dim)
                 images.append(torch.from_numpy(image).T)
-                class_ids.append(torch.tensor([classes]))
+                if classes == -1:
+                    classes = 2
+                class_ids.append(torch.tensor(classes))
             images = torch.stack(tuple(images))
             classes = torch.stack(tuple(class_ids))
         else:
